![Pynalyser Logo](https://raw.githubusercontent.com/0dminnimda/pynalyser/main/docs/logo.svg)

<h1 align="center" style="margin:-15px 0 15px 0">Static Python Code Analyzer</h1>

<p align="center" style="margin:0 0 -15px 0">
    <a href="https://github.com/0dminnimda/pynalyser/blob/main/LICENSE">
        <img alt="GitHub" src="https://img.shields.io/github/license/0dminnimda/pynalyser">
    </a>
    <img alt="PyPI - Python Version" src="https://img.shields.io/pypi/pyversions/pynalyser">
    <a href="https://github.com/0dminnimda/pynalyser">
        <img alt="GitHub Repo stars" src="https://img.shields.io/github/stars/0dminnimda/pynalyser?style=social">
    </a>
</p>

<!-- <p align="center">Powerful static analysis open to the public to explore and create amazing tools for the Python environment</p> -->

# Installation

```console
pip install pynalyser
```
